Please see [https://docs.mlcommons.org/cm4mlops/scripts/Reproducibility-and-artifact-evaluation/process-ae-users](https://docs.mlcommons.org/cm4mlops/scripts/Reproducibility-and-artifact-evaluation/process-ae-users) for the documentation of this CM script.
